OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Només visible per a les persones que coincideixen mitjançant la integració del número de telèfon a través de Talk al mòbil",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Només visible per a les persones d'aquesta instància i convidats",
    "Federated" : "Federat",
    "Only synchronize to trusted servers" : "Sincronitza només amb servidors de confiança",
    "Published" : "Publicat",
    "Synchronize to trusted servers and the global and public address book" : "Sincronitza amb servidors de confiança i amb la llibreta d'adreces global i pública",
    "Verify" : "Verifica",
    "Verifying …" : "S'està verificant …",
    "Unable to change password" : "No s'ha pogut canviar la contrasenya",
    "Very weak password" : "Contrasenya molt feble",
    "Weak password" : "Contrasenya feble",
    "So-so password" : "Contrasenya passable",
    "Good password" : "Contrasenya bona",
    "Strong password" : "Contrasenya forta",
    "An error occurred while changing your language. Please reload the page and try again." : "S'ha produït un error mentre es canviava el vostre idioma. Si us plau, recarregueu la pàgina i torneu-ho a provar.",
    "An error occurred while changing your locale. Please reload the page and try again." : "S'ha produït un error mentre es canviava la vostra configuració regional. Si us plau, recarregueu la pàgina i torneu-ho a provar.",
    "Week starts on {fdow}" : "La setmana comença en {fdow}",
    "Groups" : "Grups",
    "Group list is empty" : "La llista de grups està buida",
    "Unable to retrieve the group list" : "No s’ha pogut recuperar la llista de grups",
    "{actor} added you to group {group}" : "{actor} us ha afegit al grup {group}",
    "You added {user} to group {group}" : "Heu afegit {user} al grup {group}",
    "{actor} added {user} to group {group}" : "{actor} ha afegit {user} al grup {group}",
    "An administrator added you to group {group}" : "Un administrador us ha afegit al grup {group}",
    "An administrator added {user} to group {group}" : "Un administrador ha afegit {user} al grup {group}",
    "{actor} removed you from group {group}" : "{actor} us ha tret del grup {group}",
    "You removed {user} from group {group}" : "Heu tret {user} del grup {group}",
    "{actor} removed {user} from group {group}" : "{actor} ha tret {user} del grup {group}",
    "An administrator removed you from group {group}" : "Un administrador us ha tret del grup {group}",
    "An administrator removed {user} from group {group}" : "Un administrador ha tret {user} del grup {group}",
    "Your <strong>group memberships</strong> were modified" : "La vostra <strong>pertinença al grup</strong> ha estat modificada",
    "{actor} changed your password" : "{actor} ha canviat la vostra contrasenya",
    "You changed your password" : "Heu canviat la vostra contrasenya",
    "Your password was reset by an administrator" : "Un administrador ha restablert la vostra contrasenya",
    "Your password was reset" : "La vostra contrasenya ha estat restablerta",
    "{actor} changed your email address" : "{actor} ha canviat la vostra adreça de correu electrònic",
    "You changed your email address" : "Heu canviat la vostra adreça de correu electrònic",
    "Your email address was changed by an administrator" : "Un administrador ha canviat la vostra adreça de correu electrònic",
    "You created app password \"{token}\"" : "Heu creat \"{token}\" a l’aplicació de contrasenyes",
    "An administrator created app password \"{token}\"" : "Un administrador ha creat la contrasenya de l'aplicació \"{token}\"",
    "You deleted app password \"{token}\"" : "Heu suprimit \"{token}\" de l’aplicació de contrasenyes",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Heu reanomenat \"{token}\" a \"{newToken} a l'aplicació de contrasenyes",
    "You granted filesystem access to app password \"{token}\"" : "Heu donat accés al sistema de fitxers a l'aplicació de contrasenyes \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Heu tret l'accés al sistema de fitxers a l'aplicació de contrasenyes \"{token}\"",
    "Security" : "Seguretat",
    "You successfully logged in using two-factor authentication (%1$s)" : "Heu iniciat sessió correctament amb l'autenticació de doble factor (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ha fallat l'inici de sessió mitjançant l'autenticació de doble factor (%1$s)",
    "Remote wipe was started on %1$s" : "S'ha engegat la neteja remota a %1$s",
    "Remote wipe has finished on %1$s" : "Ha finalitzat la neteja remota a %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "S'ha modificat la vostra <strong>contrasenya</strong> o <strong>correu electrònic</strong>",
    "Could not remove app." : "No s'ha pogut suprimir l'aplicació.",
    "Could not update app." : "No s'ha pogut actualitzar l'aplicació.",
    "Wrong password" : "Contrasenya incorrecta",
    "Unable to change personal password" : "No s'ha pogut canviar la contrasenya personal",
    "Saved" : "S'ha desat",
    "No user supplied" : "No heu proporcionat cap usuari",
    "Unable to change password. Password too long." : "No s'ha pogut canviar la contrasenya. És massa llarga.",
    "Authentication error" : "Error d'autenticació",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Si us plau, proporcioneu una contrasenya d'administrador de recuperació; en cas contrari, es perdran totes les dades.",
    "Wrong admin recovery password. Please check the password and try again." : "La contrasenya d'administrador de recuperació és incorrecta. Si us plau, comproveu-la i torneu-ho a provar.",
    "Backend does not support password change, but the user's encryption key was updated." : "El rerefons no admet el canvi de contrasenya, però s'ha actualitzat la clau de xifratge de l'usuari.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instal·lació i actualització d'aplicacions a través de la botiga d'aplicacions o el Núvol Federat",
    "Federated Cloud Sharing" : "Compartició de Núvols Federats",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL està fent servir una versió %1$s antiquada (%2$s). Si us plau, actualitzeu el vostre sistema operatiu o característiques com %3$s no funcionaran amb fiabilitat.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "No s'ha pogut determinar si la versió TLS de cURL està obsoleta o no perquè s'ha produït un error durant la sol·licitud HTTPS contra https://nextcloud.com. Comproveu el fitxer de registre de Nextcloud per obtenir més detalls.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "El mòdul OPcache de PHP no està carregat. Per a un millor rendiment, es recomana carregar-lo a la instal·lació PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache està inhabilitat. Per a un millor rendiment, es recomana aplicar <code>opcache.enable=1</code> a la configuració de PHP.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache està configurat per suprimir comentaris de codi. Amb OPcache habilitat, s'ha d'establir <code>opcache.save.comments=1</code> perquè Nextcloud funcioni.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud no té permís per utilitzar l'API OPcache. Amb OPcache habilitat, us recomanem que inclogueu tots els directoris Nextcloud amb <code>opcache.restrict.api</code> o que desconfigureu aquest paràmetre per inhabilitar les restriccions de l'API OPcache i evitar errors durant les actualitzacions del nucli de Nextcloud o de l'aplicació.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud no té permís per utilitzar l'API OPcache. Us recomanem que inclogueu tots els directoris Nextcloud amb <code>1opcache.restrict.api1</code> o que desconfigureu aquest paràmetre per inhabilitar les restriccions de l'API OPcache i evitar errors durant les actualitzacions del nucli de Nextcloud o de l'aplicació.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Gairebé s'ha excedit el nombre màxim de claus d'OPcache. Per assegurar-vos que tots els scripts es puguin mantenir a la memòria cau, us recomanem que apliqueu <code>opcache.max.accelerated.files</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria intermèdia d'OPcache està gairebé plena. Per garantir que tots els scripts es puguin mantenir a la memòria cau, us recomanem que apliqueu <code>opcache.memory.consumption</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria cau de cadenes internades OPcache està gairebé plena. Per assegurar-vos que les cadenes que es repeteixen es poden emmagatzemar a la memòria cau de manera efectiva, es recomana aplicar <code>opcache.interned.strings.buffer</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
    "Invalid SMTP password." : "Contrasenya SMTP no vàlida.",
    "Email setting test" : "Prova de configuració del correu electrònic",
    "Well done, %s!" : "Ben fet, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si heu rebut aquest correu electrònic, sembla que la configuració del correu electrònic és correcta.",
    "Email could not be sent. Check your mail server log" : "No s'ha pogut enviar el correu electrònic. Comproveu el registre del servidor de correu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hi ha hagut un problema mentre s'enviava el correu electrònic. Reviseu els paràmetres. (Error: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Heu d'establir el correu electrònic d'usuari abans de poder enviar correus de prova. Aneu a %s per fer-ho.",
    "Invalid user" : "Usuari no vàlid",
    "Invalid mail address" : "Adreça de correu electrònic no vàlida",
    "Settings saved" : "S'han desat els paràmetres",
    "Unable to change full name" : "No s'ha pogut canviar el nom complet",
    "Unable to change email address" : "No s'ha pogut canviar l'adreça electrònica",
    "Unable to set invalid phone number" : "No es pot establir un número de telèfon no vàlid",
    "Unable to set invalid website" : "No es pot establir un lloc web no vàlid",
    "Some account data was invalid" : "Algunes dades del compte no eren vàlides",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Per tal de verificar el vostre compte de Twitter, publiqueu el següent tweet a Twitter (assegureu-vos de publicar-lo sense cap salt de línia):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Per tal de verificar el vostre lloc web, emmagatzemeu el següent contingut a l’arrel web a '.well-known/CloudIdVerificationCode.txt' (assegureu-vos que el text complet és en una línia):",
    "%1$s changed your password on %2$s." : "%1$s ha canviat la vostra contrasenya a %2$s.",
    "Your password on %s was changed." : "La vostra contrasenya a %s ha canviat.",
    "Your password on %s was reset by an administrator." : "La vostra contrasenya a %s ha estat restablerta per un administrador.",
    "Your password on %s was reset." : "La vostra contrasenya a %s ha estat restablerta.",
    "Password for %1$s changed on %2$s" : "Contrasenya per %1$s canviada a %2$s",
    "Password changed for %s" : "Contrasenya canviada per %s",
    "If you did not request this, please contact an administrator." : "Si no ho heu sol·licitat, poseu-vos en contacte amb un administrador.",
    "Your email address on %s was changed." : "La vostra adreça de correu electrònic a %s ha canviat.",
    "Your email address on %s was changed by an administrator." : "La vostra adreça de correu electrònic a %s ha estat canviada per un administrador.",
    "Email address for %1$s changed on %2$s" : "Adreça de correu electrònic per %1$s canviada a %2$s",
    "Email address changed for %s" : "Adreça de correu electrònic canviada per %s",
    "The new email address is %s" : "La nova adreça de correu electrònic és %s",
    "Your %s account was created" : "S'ha creat el vostre compte %s",
    "Welcome aboard" : "Us donem la benvinguda",
    "Welcome aboard %s" : "Us donem la benvinguda, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Benvingut al compte %s, podeu afegir, protegir i compartir les vostres dades.",
    "Your username is: %s" : "El vostre nom d'usuari és: %s",
    "Set your password" : "Establiu la vostra contrasenya",
    "Go to %s" : "Ves a %s",
    "Install Client" : "Instal·la el Client",
    "Logged in user must be a subadmin" : "L’usuari que ha iniciat la sessió ha de ser un subadministrador",
    "Apps" : "Aplicacions",
    "Settings" : "Paràmetres",
    "Personal" : "Personal",
    "Administration" : "Administració",
    "Additional settings" : "Paràmetres addicionals",
    "Administration privileges" : "Privilegis d'administració",
    "Groupware" : "Treball en grup",
    "Overview" : "Resum",
    "Basic settings" : "Configuració bàsica",
    "Sharing" : "Compartició",
    "Personal info" : "Informació personal",
    "Mobile & desktop" : "Mòbil i escriptori",
    "Email server" : "Servidor de correu electrònic",
    "Security & setup warnings" : "Avisos de seguretat i configuració",
    "Background jobs" : "Tasques de fons",
    "Create" : "Crea",
    "Change" : "Canvia",
    "Delete" : "Suprimeix",
    "Reshare" : "Tornar a compartir",
    "Unlimited" : "Il·limitat",
    "Verifying" : "S'està verificant",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Hi ha un treball en segon pla pendent que de comprovar els certificats SSL importats per l'usuari. Comproveu-ho més tard.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hi ha alguns certificats SSL importats per l'usuari que ja no s'utilitzen amb Nextcloud 21. Es poden importar en la línia d'ordres a través de l'ordre «occ security:certificates:import». A continuació se'n mostren els camins dins del directori de dades.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "S'han trobat UUID no vàlids d'usuaris o grups LDAP. Reviseu els paràmetres de l'\"Anul·lació de detecció d'UUID\" a la part Experta de la configuració LDAP i utilitzeu \"occ ldap:update-uuid\" per actualitzar-los.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "L'antic format de xifratge del servidor està habilitat. Recomanem desactivar-ho.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MariaDB 10.2 o superior.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MySQL 8.0 o MariaDB 10.2 o superior.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "S'utilitza la versió \"%s\" de PostgreSQL . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen PostgreSQL 9.6 o superior.",
    "Profile information" : "Informació del perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Imatge del perfil, nom complet, correu electrònic, número de telèfon, adreça, lloc web, Twitter, organització, rol, titular, biografia i si el vostre perfil està habilitat",
    "Nextcloud settings" : "Paràmetres del Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Aquí podeu decidir quin grup pot accedir a certes seccions dels paràmetres d'administració.",
    "None" : "Cap",
    "Unable to modify setting" : "No es pot modificar el paràmetre",
    "Two-Factor Authentication" : "Autenticació de doble factor",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L’autenticació de doble factor pot ser forçada per a tots els usuaris i grups específics. Si no tenen un proveïdor de doble factor configurat, no podran accedir en el sistema.",
    "Enforce two-factor authentication" : "Força l'autenticació de doble factor",
    "Limit to groups" : "Limita per grups",
    "Enforcement of two-factor authentication can be set for certain groups only." : "L’obligació d'autenticació de doble factor es pot definir només per a certs grups.",
    "Two-factor authentication is enforced for all members of the following groups." : "L’autenticació de doble factor està obligada per a tots els membres dels següents grups.",
    "Enforced groups" : "Grups forçats",
    "Two-factor authentication is not enforced for members of the following groups." : "L'autenticació de doble factor no està obligada per als membres dels següents grups.",
    "Excluded groups" : "Grups exclosos",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quan es seleccionen/exclouen grups, es fa servir la lògica següent per determinar si un usuari té 2FA (Autenticació de 2 Factors) forçosa: si no hi ha grups seleccionats, 2FA està activada per a tothom, a excepció de membres dels grups exclosos. Si els grups estan seleccionats, 2FA està activada per a tots els membres d'aquests. Si un usuari està tant en un grup seleccionat com exclòs, els seleccionats tenen prioritat i 2FA s'imposa.",
    "Save changes" : "Desa els canvis",
    "All" : "Tots",
    "Limit app usage to groups" : "Limita l’ús de l’aplicació als grups",
    "No results" : "No hi ha resultats",
    "Update to {version}" : "Actualitza a {version}",
    "Remove" : "Suprimeix",
    "Disable" : "Desactiva",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió mínima de Nextcloud assignada. Això serà un error en el futur.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió màxima de Nextcloud assignada. Això serà un error en el futur.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
    "View in store" : "Mostra-ho al magatzem",
    "Visit website" : "Visita el lloc web",
    "Report a bug" : "Informa d'un error",
    "User documentation" : "Documentació per a usuaris",
    "Admin documentation" : "Documentació per a administradors",
    "Developer documentation" : "Documentació per a desenvolupadors",
    "This app is supported via your current Nextcloud subscription." : "Aquesta aplicació és compatible amb la vostra subscripció actual a Nextcloud.",
    "Supported" : "Compatible",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les aplicacions destacades es desenvolupen per i dins de la comunitat. Ofereixen funcionalitats centrals i estan preparades per ser emprades en producció.",
    "Featured" : "Destacat",
    "Update to {update}" : "Actualitza a {update}",
    "All apps are up-to-date." : "Totes les aplicacions estan actualitzades.",
    "Results from other categories" : "Resultats d'altres categories",
    "No apps found for your version" : "No s'han trobat aplicacions per la vostra versió",
    "Disable all" : "Desactiva-ho tot",
    "Enable all" : "Activa-ho tot",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n  aplicació té una actualització disponible","%n aplicacions tenen una actualització disponible"],
    "_Update_::_Update all_" : ["Actualitza","Actualitza tot"],
    "Marked for remote wipe" : "Marcat per netejar remotament",
    "Device settings" : "Paràmetres del dispositiu",
    "Allow filesystem access" : "Permet l'accés al sistema de fitxers",
    "Rename" : "Canvia el nom",
    "Revoke" : "Revoca",
    "Wipe device" : "Esborra el dispositiu",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revocar aquest testimoni podria evitar la neteja del dispositiu si encara no ha començat.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome per a Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "Aplicació iOS de {productName}",
    "{productName} Android app" : "Aplicació Android de {productName} ",
    "{productName} Talk for iOS" : "Talk for iOS de {productName} ",
    "{productName} Talk for Android" : "Talk for Android de {productName} ",
    "Sync client - {os}" : "Client de sincronització - {os}",
    "This session" : "Aquesta sessió",
    "Device" : "Dispositiu",
    "Last activity" : "Darrera activitat",
    "Devices & sessions" : "Dispositius i sessions",
    "Web, desktop and mobile clients currently logged in to your account." : "Clients Web, d'escriptori i mòbils connectats actualment al vostre compte.",
    "Do you really want to wipe your data from this device?" : "Esteu segurs de que voleu netejar les vostres dades d'aquest dispositiu?",
    "Confirm wipe" : "Confirma neteja",
    "Error while creating device token" : "S'ha produït un error mentre es creava el testimoni del dispositiu",
    "Error while updating device token scope" : "S'ha produït un error mentre s'actualitzava l’abast de testimonis del dispositiu",
    "Error while updating device token name" : "S'ha produït un error mentre s'actualitzava el nom del testimoni del dispositiu",
    "Error while deleting the token" : "S'ha produït un error mentre se suprimia el testimoni",
    "Error while wiping the device with the token" : "S'ha produït un error mentre es netejava el dispositiu amb el token",
    "App name" : "Nom de l'aplicació",
    "Create new app password" : "Crea una nova contrasenya d'aplicació",
    "Use the credentials below to configure your app or device." : "Utilitzeu les credencials de sota per configurar la vostra aplicació o dispositiu.",
    "For security reasons this password will only be shown once." : "Per raons de seguretat aquesta contrasenya només es mostrarà una vegada.",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "Done" : "Fet",
    "Show QR code for mobile apps" : "Mostra el codi QR per aplicacions mòbils",
    "Copied!" : "S'ha copiat!",
    "Copy" : "Copia",
    "Could not copy app password. Please copy it manually." : "No s’ha pogut copiar la contrasenya de l’aplicació. Copieu-la manualment.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Perquè el servidor funcioni correctament, és important configurar els treballs en segon pla correctament. Cron és el paràmetre recomanat. Per a més informació, vegeu la documentació.",
    "Last job execution ran {time}. Something seems wrong." : "L'última execució de la tasca s'ha executat a les {time}. Sembla que hi ha algun problema.",
    "Background job did not run yet!" : "La tasca en segon pla encara no s'ha executat",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Executeu una tasca amb cada pàgina carregada. Cas d'ús: instància d'un sol usuari.",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (recomanat)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Per executar això es necessita l'extensió POSIX de PHP. Per més detalls, vegeu {linkstart}documentació de PHP{linkend}.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Utilitzeu el servei cron del sistema per a cridar el fitxer cron.php cada 5 minuts. Recomanat per a totes les instàncies.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php l'ha d'executar l'usuari del sistema \"{user}\".",
    "Unable to update background job mode" : "No s'ha pogut actualitzar el mode de tasca en segon pla",
    "Profile" : "Perfil",
    "Enable or disable profile by default for new users." : "Habiliteu o deshabiliteu el perfil per defecte per als usuaris nous.",
    "Enable" : "Activa",
    "Unable to update profile default setting" : "No s'ha pogut actualitzar la configuració predeterminada del perfil",
    "Server-side encryption" : "Encriptació en el servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "L'encriptació en el servidor permet xifrar els fitxers que s'hi carreguen. Això afecta al rendiment, així que activeu-ho només si és necessari.",
    "Enable server-side encryption" : "Activa l'encriptació en el servidor",
    "Please read carefully before activating server-side encryption:" : "Llegiu atentament abans d'activar el xifratge del servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Un cop s’activi l'encriptació, tots els fitxers carregats al servidor des d'aquest punt cap endavant quedaran encriptats al servidor. Només serà possible desactivar l'encriptació posteriorment si el mòdul criptogràfic actiu té aquesta funció, i es compleixen totes les pre-condicions (p. ex. definir una clau de recuperació).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "L'encriptació per si mateixa no garanteix la seguretat del sistema. Consulteu la documentació per a més informació sobre com funciona l'aplicació d'encriptació i els casos d'ús suportats.",
    "Be aware that encryption always increases the file size." : "Tingueu en compte que l'encriptació sempre augmenta la mida del fitxer.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Sempre és bó crear còpies de seguretat de les vostres dades amb regularitat, en el cas de encriptació assegureu-vos de desar les claus d'encriptació juntament amb les vostres dades a la còpia de seguretat.",
    "This is the final warning: Do you really want to enable encryption?" : "Avís final: Realment voleu activar l'encriptació?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No s'ha carregat cap mòdul d'encriptació, si us plau activeu un mòdul d'encriptació al menú d'aplicacions.",
    "Select default encryption module:" : "Seleccioneu el mòdul criptogràfic per defecte:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Heu de migrar les claus de xifratge del xifratge anterior (ownCloud .= 8.0) al nou. Habiliteu el \"Mòdul de xifratge peredeterminat\" i executeu {command}",
    "Unable to update server side encryption config" : "No es pot actualitzar la configuració del xifratge de la banda del servidor",
    "Rename group" : "Canvia el nom del grup",
    "Remove group" : "Suprimeix el grup",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Esteu a punt de suprimir el grup {group}. Els usuaris NO seran suprimits.",
    "Please confirm the group removal " : "Confirmeu la supressió del grup ",
    "Current password" : "Contrasenya actual",
    "New password" : "Contrasenya nova",
    "Change password" : "Canvia la contrasenya",
    "Your profile picture" : "La vostra imatge de perfil",
    "Upload profile picture" : "Puja la imatge de perfil",
    "Choose profile picture from files" : "Trieu una imatge de perfil als fitxers",
    "Remove profile picture" : "Treu la imatge de perfil",
    "png or jpg, max. 20 MB" : "png o jpg, màx. 20 MB",
    "Picture provided by original account" : "Imatge proporcionada pel compte original",
    "Cancel" : "Cancel·la",
    "Set as profile picture" : "Estableix com a imatge de perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tingueu en compte que la imatge de perfil pot tardar fins a 24 hores a actualitzar-se  a tot arreu.",
    "Choose your profile picture" : "Trieu la vostra imatge de perfil",
    "Please select a valid png or jpg file" : "Seleccioneu un fitxer png o jpg vàlid",
    "Error setting profile picture" : "Error en establir la imatge de perfil",
    "Error cropping profile picture" : "Error en retallar la imatge de perfil",
    "Error saving profile picture" : "Error en desar la imatge de perfil",
    "Error removing profile picture" : "Error en treure la imatge de perfil",
    "Your biography" : "La vostra biografia",
    "Your full name" : "El vostre nom complet",
    "Email options" : "Opcions de correu electrònic",
    "Primary email for password reset and notifications" : "Adreça electrònica principal per a restablir la contrasenya i per a les notificacions",
    "Remove primary email" : "Treu l'adreça electrònica principal",
    "Delete email" : "Treu l'adreça electrònica",
    "Your email address" : "El vostre correu electrònic",
    "No email address set" : "No s'ha establert cap adreça de correu electrònic",
    "Language" : "Llengua",
    "Help translate" : "Ajudeu-nos amb la traducció",
    "No language set" : "No s'ha establert cap idioma",
    "Your phone number" : "El vostre número de telèfon",
    "Your website" : "El teu lloc web",
    "Add" : "Afegeix",
    "You do not have permissions to see the details of this user" : "No teniu els permisos necessaris per veure els detalls d'aquest usuari",
    "Add new password" : "Afegeix una nova contrasenya",
    "Add new email address" : "Afegeix una nova adreça de correu electrònic",
    "Set user as admin for" : "Posa l'usuari com a administrador per",
    "Select user quota" : "Selecciona la quota d'usuari",
    "Delete user" : "Suprimeix l'usuari",
    "Wipe all devices" : "Esborra tots els dispositius",
    "Disable user" : "Desactiva l'usuari",
    "Enable user" : "Activa l'usuari",
    "Resend welcome email" : "Torna a enviar el correu electrònic de benvinguda",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En cas de perdre un dispositiu o sortir de l’organització, es pot esborrar de forma remota les dades del Nextcloud de tots els dispositius associats a {userid}. Només funciona si els dispositius estan connectats a Internet.",
    "Remote wipe of devices" : "Neteja remota de dispositius",
    "Wipe {userid}'s devices" : "Neteja els dispositius de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Suprimeix completament el compte de {userid} inclosos tots els seus fitxers personals, dades d'aplicacions, etc.",
    "Account deletion" : "Supressió del compte",
    "Delete {userid}'s account" : "Suprimeix el compte de {userid}",
    "Welcome mail sent!" : "S'ha enviat el correu electrònic de benvinguda!",
    "Edit User" : "Edita Usuari",
    "Toggle user actions menu" : "Commuta el menú d'accions d'usuari",
    "{size} used" : "{size} en ús",
    "New user" : "Nou usuari",
    "Will be autogenerated" : "Serà auto-generat",
    "Display name" : "Nom per mostrar",
    "Email" : "Correu electrònic",
    "Default language" : "Llengua per defecte",
    "Add a new user" : "Afegeix un nou usuari",
    "Group admin for" : "Administrador de grup per",
    "Quota" : "Quota",
    "User backend" : "Rerefons d'usuari",
    "Storage location" : "Ubicació de l'emmagatzematge",
    "Last login" : "Darrer accés",
    "No users in here" : "No hi ha usuaris aquí dins",
    "Default quota" : "Quota per defecte",
    "Common languages" : "Llengües freqüents",
    "Other languages" : "Altres llengües",
    "Password change is disabled because the master key is disabled" : "El canvi de contrasenya està desactivat perquè la clau mestra està desactivada",
    "Passwordless authentication requires a secure connection." : "L'autenticació sense contrasenya necessita una connexió segura.",
    "Add WebAuthn device" : "Afegeix un dispositiu WebAuthn",
    "Please authorize your WebAuthn device." : "Si us plau, autoritzeu el vostre dispositiu WebAuthn.",
    "Name your device" : "Anomeneu el vostre dispositiu",
    "Adding your device …" : "S'està afegint el vostre dispositiu …",
    "Server error while trying to add WebAuthn device" : "Error del servidor mentre s'intentava afegir un dispositiu WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Error del servidor mentre s'intentava completar el registre del dispositiu WebAuthn",
    "Unnamed device" : "Dispositiu sense nom",
    "Passwordless Authentication" : "Autenticació sense Contrasenya",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura el teu compte per a l'autenticació sense contrasenya seguint l'estàndard FIDO2.",
    "No devices configured." : "No hi han dispositius configurats.",
    "The following devices are configured for your account:" : "Els següents dispositius estan configurats per al vostre compte:",
    "Your browser does not support WebAuthn." : "El vostre navegador no suporta WebAuthn.",
    "Your apps" : "Les vostres aplicacions",
    "Active apps" : "Aplicacions actives",
    "Disabled apps" : "Aplicacions desactivades",
    "Updates" : "Actualitzacions",
    "App bundles" : "Paquets d'aplicacions",
    "Featured apps" : "Aplicacions destacades",
    "{license}-licensed" : "sota la llicència - {license}",
    "Details" : "Detalls",
    "Changelog" : "Registre de canvis",
    "by {author}\n{license}" : "{author}\n{license}",
    "Enter group name" : "Introduïu el nom del grup",
    "Add group" : "Afegeix un grup",
    "Active users" : "Usuaris actius",
    "Admins" : "Administradors",
    "Disabled users" : "Usuaris desactivats",
    "Default quota:" : "Quota per defecte:",
    "Select default quota" : "Seleccioneu la quota per defecte",
    "Show Languages" : "Mostra els idiomes",
    "Show last login" : "Mostra el darrer inici de sessió",
    "Show user backend" : "Mostra el rerefons d'usuari",
    "Show storage path" : "Mostra la ubicació del magatzem",
    "Send email to new user" : "Enviar correu electrònic al nou usuari",
    "Not saved" : "No s'ha desat",
    "Sending…" : "S'està enviant…",
    "Email sent" : "S'ha enviat el correu electrònic",
    "Location" : "Ubicació",
    "Profile picture" : "Foto de perfil",
    "About" : "Quant a",
    "Full name" : "Nom complet",
    "Headline" : "Titular",
    "Phone number" : "Número de telèfon",
    "Role" : "Càrrec",
    "Twitter" : "Twitter",
    "Website" : "Lloc web",
    "Hide" : "Amaga",
    "Download and enable" : "Descarrega i activa",
    "Enable untested app" : "Activa aplicacions no provades",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aquesta aplicació no està marcada com a compatible amb la vostra versió de Nextcloud. Si continueu, encara podreu instal·lar l’aplicació. Tingueu en compte que pot ser que l’aplicació no funcioni correctament.",
    "Never" : "Mai",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'aplicació s'ha activat però ha de ser actualitzada. Sereu redirigits a la pàgina d’actualització d'aquí 5 segons.",
    "Administrator documentation" : "Documentació d'administrador",
    "Documentation" : "Documentació",
    "Forum" : "Fòrum",
    "Login" : "Inici de sessió",
    "Plain" : "Net",
    "NT LAN Manager" : "Gestor NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Obre la documentació",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "És important configurar aquest servidor per poder enviar correus electrònics, com ara per poder restablir la contrasenya i notificacions.",
    "Send mode" : "Mode d'enviament",
    "Encryption" : "Xifratge",
    "Sendmail mode" : "Mode sendmail",
    "From address" : "Des de l'adreça",
    "Authentication method" : "Mètode d'autenticació",
    "Authentication required" : "Cal autenticació",
    "Server address" : "Adreça del servidor",
    "Port" : "Port",
    "Credentials" : "Credencials",
    "SMTP Username" : "Nom d'usuari SMTP",
    "SMTP Password" : "Contrasenya SMTP",
    "Save" : "Desa",
    "Send email" : "Envia el correu electrònic",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "És important per a la seguretat i el rendiment de la vostra instància que tot estigui configurat correctament. Per ajudar-vos, fem algunes comprovacions automàtiques. Si us plau, consulteu la documentació enllaçada per obtenir més informació.",
    "All checks passed." : "Totes les comprovacions correctes.",
    "There are some errors regarding your setup." : "Hi ha alguns errors pel que fa a la vostra configuració.",
    "There are some warnings regarding your setup." : "Hi ha algunes advertències pel que fa a la vostra configuració.",
    "Checking for system and security issues." : "S'estan comprovant incidències del sistema i de seguretat.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Si us plau reviseu les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guies d’instal·lació ↗</a>, i comproveu si hi ha errors o advertències en el <a href=\"%2$s\">registre</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Reviseu la seguretat del vostre Nextcloud mitjançant el <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nostre escaneig de seguretat ↗</a>.",
    "Version" : "Versió",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Com a administrador, podeu afinar els ajustaments per compartir fitxers. Si us plau, per més informació llegiu la documentació.",
    "Allow apps to use the Share API" : "Permet que les aplicacions utilitzin l'API de compartir",
    "Set default expiration date for shares" : "Estableix la data de caducitat per defecte per comparticions",
    "day(s)" : "dies",
    "Enforce expiration date" : "Força la data de caducitat",
    "Allow public uploads" : "Permet càrregues públiques",
    "Always ask for a password" : "Demana sempre una contrasenya",
    "Enforce password protection" : "Força la protecció amb contrasenya",
    "Set default expiration date" : "Estableix la data de caducitat per defecte",
    "Allow resharing" : "Permet compartir de nou",
    "Allow sharing with groups" : "Permetre compartir amb grups",
    "Restrict users to only share with users in their groups" : "Restringeix als usuaris a compartir només amb usuaris del seu grup",
    "Exclude groups from sharing" : "Exclou grups de compartició",
    "These groups will still be able to receive shares, but not to initiate them." : "Aquests grups encara podran rebre comparticions, però no en podran iniciar.",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostra el text de descàrrega de responsabilitat a la pàgina de l'enllaç públic de càrrega (només es mostra quan la llista de fitxers està oculta).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Aquest text es mostrarà a la pàgina de càrrega d’enllaç públic quan la llista de fitxers estigui amagada.",
    "Default share permissions" : "Permisos de compatició per defecte",
    "Reasons to use Nextcloud in your organization" : "Motius per a utilitzar Nextcloud en la vostra organització",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolupat per la {communityopen}comunitat Nextcloud{linkclose}, el {githubopen}codi font{linkclose} es troba sota la llicència {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Poseu un m’agrada a la nostra pàgina de Facebook",
    "Follow us on Twitter" : "Seguiu-nos a Twitter",
    "Follow us on Mastodon" : "Seguiu-nos a Mastodon",
    "Check out our blog" : "Consulteu el nostre bloc",
    "Subscribe to our newsletter" : "Subscriviu-vos al nostre butlletí",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Aquest llançament de la comunitat de Nextcloud no és compatible i les notificacions instantànies no estan disponibles.",
    "You are a member of the following groups:" : "Sou membre dels grups següents:",
    "You are using <strong>%s</strong>" : "Esteu utilitzant <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Esteu utilitzant <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Locale" : "Configuració regional",
    "Use a second factor besides your password to increase security for your account." : "Feu servir un segon factor a més de la vostra contrasenya per augmentar la seguretat del vostre compte.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilitzeu aplicacions de tercers per a connectar-vos a Nextcloud, assegureu-vos de crear i configurar una contrasenya d'aplicació per a cadascuna abans d'habilitar l'autenticació de segon factor.",
    "Migration in progress. Please wait until the migration is finished" : "Migració en procés. Si us plau, espereu fins que finalitzi la migració",
    "Migration started …" : "S'ha iniciat la migració …",
    "Select a profile picture" : "Seleccioneu una imatge de perfil",
    "Couldn't remove app." : "No s'ha pogut suprimit l'aplicació.",
    "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "El mòdul de suport no admet canvis de contrasenya, però la clau de xifrat de l'usuari ha estat actualitzada satisfactòriament.",
    "You need to set your user email before being able to send test emails." : "Heu d'establir un nom d'usuari abans de poder enviar correus de prova.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Revocant aquest token impedirà la neteja del vostre dispositiu si encara no ha començat.",
    "All languages" : "Tots els idiomes",
    "Everyone" : "Tothom",
    "An error occured during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
    "Test email settings" : "Prova els paràmetres de correu electrònic",
    "Please read carefully before activating server-side encryption: " : "Si us plau, llegiu atentament abans d'activar l'encriptació en el servidor: ",
    "Enable encryption" : "Activa l'encriptació",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Heu de migrar les claus d'encriptació de l'encriptació antiga (ownCloud <= 8.0) a la nova. Si us plau activeu el “Mòdul criptogràfic per defecte\" i executeu ‘occ encryption:migrate’",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Heu de migrar les claus d'encriptació de l'encriptació antiga (ownCloud <= 8.0) a la nova.",
    "Start migration" : "Inicia la migració",
    "Last job execution ran %s. Something seems wrong." : "La darrera tasca es va executar %s. Alguna cosa sembla malament.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Algunes feines no s’han executat des de %s. Considereu augmentar la freqüència d’execució.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Algunes feines no s’han executat des de %s. Considereu canviar al cron del sistema.",
    "Last job ran %s." : "La darrera tasca es va executar %s.",
    "Background job didn’t run yet!" : "La tasca de fons encara no s'ha executat!",
    "Pick background job setting" : "Trieu la configuració de la tasca en segon pla",
    "Recommended" : "Recomanat",
    "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php ha de ser executat per l'usuari del sistema \"%s\".",
    "days" : "dies",
    "Upload new" : "Carrega'n una de nova",
    "Select from Files" : "Selecciona dels Fitxers",
    "Remove image" : "Suprimeix imatge",
    "Choose as profile picture" : "Tria una imatge de perfil",
    "No display name set" : "No s'ha establert cap nom para mostrar",
    "Address" : "Adreça",
    "Your postal address" : "La vostra adreça postal",
    "It can take up to 24 hours before the account is displayed as verified." : "Pot trigar fins a 24 hores abans que el compte es mostri com a verificat.",
    "Link https://…" : "Enllaç https://…",
    "Twitter handle @…" : "Compte Twitter @…",
    "Admin privileges" : "Privilegis d'administrador",
    "Avatar" : "Avatar"
},
"nplurals=2; plural=(n != 1);");
